@@ -36,7 +36,6 @@
 #include <QMap>
 
 class TransferCache;
-class MessageModel;
 class QNetworkAccessManager;
 
 class DownloadJob : public QObject
@@ -72,21 +71,26 @@ class DownloadManager : public QObject
 {
 	Q_OBJECT
 public:
-	DownloadManager(TransferCache *m_transferCache, MessageModel *m_model, QObject *parent = nullptr);
+	DownloadManager(TransferCache *m_transferCache, QObject *parent = nullptr);
 	~DownloadManager();
 
 signals:
 	void startDownloadRequested(const QString &msgId, const QString &url);
 	void abortDownloadRequested(const QString &msgId);
 
-public slots:
+private slots:
+	/**
+	 * Downloads an attached media file of a message
+	 *
+	 * @param msgId The message
+	 * @param url the media url from the message
+	 */
 	void startDownload(const QString &msgId, const QString &url);
 	void abortDownload(const QString &msgId);
 
 private:
 	QNetworkAccessManager *m_netMngr;
 	TransferCache *m_transferCache;
-	MessageModel *m_model;
 
 	QMap<QString, DownloadJob *> m_downloads;
 };
